# VMwareCloud AWS Disaster Recovery as a Service
 
vmwarecloud-draas is a client library that contains disaster management and recovery related APIs for your Software Defined Data Centres (SDDCs) running on VMware Cloud on Amazon Web Services (AWS). This library is part of [vSphere Automation SDK for Python](https://github.com/vmware/vsphere-automation-sdk-python).
 
[Source code](https://github.com/vmware/vsphere-automation-sdk-python/tree/master/lib/src/vmwarecloud-draas) | [Package (PyPI)](https://pypi.org/project/vmwarecloud-draas/) | [Python API documentation](https://vmware.github.io/vsphere-automation-sdk-python/vmc-draas/index.html)
 
## Getting started
 
### Prerequisites
 
- Python 3.8+ is required to use this package.
 
### Install the package
 
```bash
pip install vmwarecloud-draas
```
